# -*- coding: utf-8 -*-
import os
import subprocess
import tkinter as tk
from tkinter import ttk, messagebox, filedialog
import ttkbootstrap as ttk
from ttkbootstrap.constants import *
import threading
import signal
import re
import winreg
import sys

class YouTubeDownloaderApp:
    def __init__(self, root):
        self.root = root
        self.root.title("מוריד סרטוני יוטיוב")
        self.root.geometry("600x950")
        
        # Set gray dark theme
        style = ttk.Style("darkly")
        
        # Create a custom style for label frames with visible white text
        style.configure("WhiteLabel.TLabelframe", background="#333333", bordercolor="#444444")
        style.configure("WhiteLabel.TLabelframe.Label", foreground="#FFFFFF", background="#444444", 
                         font=("Segoe UI", 11, "bold"))
        
        # Configure other styles
        style.configure(".", font=("Segoe UI", 10))
        style.configure("TFrame", background="#333333")
        style.configure("TButton", background="#555555", foreground="white")
        style.configure("TLabel", background="#333333", foreground="white")
        style.configure("TEntry", fieldbackground="#444444", foreground="white")
        
        self.main_container = ttk.Frame(self.root, padding="20")
        self.main_container.pack(fill="both", expand=True)
        self.root.configure(bg="#333333")
        
        self.create_header(self.main_container)
        self.create_url_section(self.main_container)
        self.create_path_section(self.main_container)
        self.create_options_section(self.main_container)
        self.create_download_section(self.main_container)
        self.create_log_section(self.main_container)
        
        # הגדרת תיקיית ברירת מחדל להורדות
        default_path = os.path.join(os.path.expanduser("~"), "Downloads")
        self.output_path.insert(0, default_path)
        
        if not self.check_ffmpeg():
            messagebox.showerror(
                "שגיאה",
                "קובץ FFMPEG.exe חסר בתיקיית התוכנה. אנא וודא שהקובץ קיים."
            )
            root.destroy()
            return

    def create_header(self, container):
        header_frame = ttk.Frame(container)
        header_frame.pack(fill="x", pady=(0, 20))
        
        header = ttk.Label(
            header_frame,
            text="הורדת סרטונים מיוטיוב",
            font=("Segoe UI", 24, "bold"),
            foreground="white",
            padding=10
        )
        header.pack(pady=10)

    def create_url_section(self, container):
        # Create with enhanced visibility for the label - using custom WhiteLabel style
        url_frame = ttk.LabelFrame(container, text="קישור", padding="15", style="WhiteLabel.TLabelframe")
        url_frame.pack(fill="x", pady=(0, 15))
        
        self.url_entry = ttk.Entry(
            url_frame,
            width=60,
            font=("Segoe UI", 10),
            bootstyle="dark"
        )
        self.url_entry.pack(fill="x", pady=(5, 10))
        
        self.url_context_menu = tk.Menu(self.root, tearoff=0)
        self.url_context_menu.add_command(label="גזור", command=self.cut_url)  # הוספת אופציית גזירה
        self.url_context_menu.add_command(label="העתק", command=self.copy_url)
        self.url_context_menu.add_command(label="הדבק", command=self.paste_url)
        self.url_context_menu.add_command(label="בדוק לוח העתקה", command=self.check_clipboard_for_youtube)
        
        self.url_entry.bind("<Button-3>", self.show_context_menu)
        self.url_entry.bind("<Control-x>", lambda e: self.cut_url())    # גזירה עם Ctrl+X
        self.url_entry.bind("<Control-c>", lambda e: self.copy_url())   # העתקה עם Ctrl+C
        self.url_entry.bind("<Control-v>", lambda e: self.paste_url())  # הדבקה עם Ctrl+V
        self.url_entry.bind("<Control-x>", self.cut_url)    # גזירה עם Ctrl+X
        self.url_entry.bind("<Control-c>", self.copy_url)   # העתקה עם Ctrl+C
        self.url_entry.bind("<Control-v>", self.paste_url)  # הדבקה עם Ctrl+V
        
        # הגדרת כל קיצורי המקלדת
        self.url_entry.bind("<Control-a>", self.select_all)        # בחירת הכל
        self.url_entry.bind("<Control-x>", self.cut_url)          # גזירה
        self.url_entry.bind("<Control-c>", self.copy_url)         # העתקה
        self.url_entry.bind("<Control-v>", self.paste_url)        # הדבקה
        self.url_entry.bind("<Delete>", self.delete_selection)    # מחיקה
        self.url_entry.bind("<BackSpace>", self.backspace)        # Backspace
        
        # הגדרת קיצורי מקלדת - תמיכה באנגלית ועברית
        self.url_entry.bind("<Control-KeyPress>", self.handle_keypress)  # תפיסת כל לחיצות Control
        
        # מחיקת הבינדינג הישנים שגורמים לשגיאה
        # self.url_entry.bind("<Control-type a>", self.select_all)  # ש - לא תקין
        # self.url_entry.bind("<Control-type c>", self.copy_url)   # ב - לא תקין
        # self.url_entry.bind("<Control-type v>", self.paste_url)  # ה - לא תקין
        # self.url_entry.bind("<Control-type x>", self.cut_url)    # ס - לא תקין
        
        # מקשי מחיקה
        self.url_entry.bind("<Delete>", self.delete_selection)    
        self.url_entry.bind("<BackSpace>", self.backspace)        
        
        # הוספת event binding לזיהוי לחיצות מקשים בכללי
        self.url_entry.bind("<Key>", self.handle_keypress)
        
        buttons_frame = ttk.Frame(url_frame)
        buttons_frame.pack(fill="x")
        
        # כפתור בדיקת לוח העתקה
        clipboard_button = ttk.Button(
            buttons_frame,
            text="בדוק לוח העתקה",
            command=self.check_clipboard_for_youtube,
            bootstyle="light-outline",
            width=15
        )
        clipboard_button.pack(side="left", padx=5)
        
        copy_button = ttk.Button(
            buttons_frame,
            text="העתק",
            command=self.copy_url,
            bootstyle="light-outline",
            width=15
        )
        copy_button.pack(side="right", padx=5)
        
        paste_button = ttk.Button(
            buttons_frame,
            text="הדבק",
            command=self.paste_url,
            bootstyle="light-outline",
            width=15
        )
        paste_button.pack(side="right")

    def create_path_section(self, container):
        path_frame = ttk.LabelFrame(container, text="תיקיית שמירה", padding="15", style="WhiteLabel.TLabelframe")
        path_frame.pack(fill="x", pady=15)
        
        self.output_path = ttk.Entry(
            path_frame,
            font=("Segoe UI", 10),
            bootstyle="dark"
        )
        self.output_path.pack(side="left", fill="x", expand=True, padx=(0, 10))
        
        browse_button = ttk.Button(
            path_frame,
            text="בחר תיקייה",
            command=self.select_directory,
            bootstyle="light-outline",
            width=15
        )
        browse_button.pack(side="right")

    def create_options_section(self, container):
        options_frame = ttk.LabelFrame(container, text="אפשרויות הורדה", padding="15", style="WhiteLabel.TLabelframe")
        options_frame.pack(fill="x", pady=15)
        
        # אפשרות עקיפת נטפרי
        netfree_frame = ttk.Frame(options_frame)
        netfree_frame.pack(fill="x", pady=(5, 15))
        
        self.netfree_bypass_var = tk.BooleanVar(value=True)
        ttk.Checkbutton(
            netfree_frame,
            text="מצב תאימות לנטפרי (מומלץ)",
            variable=self.netfree_bypass_var,
            bootstyle="round-toggle"
        ).pack(side="right", padx=5)
        
        # סוג הורדה
        format_frame = ttk.Frame(options_frame)
        format_frame.pack(fill="x", pady=(0, 15))
        
        ttk.Label(
            format_frame,
            text="סוג הורדה:",
            font=("Segoe UI", 10, "bold")
        ).pack(side="right", padx=5)
        
        self.format_var = tk.StringVar(value="video")
        ttk.Radiobutton(
            format_frame,
            text="וידאו",
            variable=self.format_var,
            value="video",
            bootstyle="light-toolbutton"
        ).pack(side="right", padx=5)
        
        ttk.Radiobutton(
            format_frame,
            text="אודיו בלבד",
            variable=self.format_var,
            value="audio",
            bootstyle="light-toolbutton"
        ).pack(side="right", padx=5)
        
        # סוג תוכן
        content_frame = ttk.Frame(options_frame)
        content_frame.pack(fill="x")
        
        ttk.Label(
            content_frame,
            text="סוג תוכן:",
            font=("Segoe UI", 10, "bold")
        ).pack(side="right", padx=5)
        
        self.content_type = tk.StringVar(value="single")
        for text, value in [
            ("סרטון בודד", "single"),
            ("פלייליסט", "playlist"),
            ("ערוץ", "channel")
        ]:
            ttk.Radiobutton(
                content_frame,
                text=text,
                variable=self.content_type,
                value=value,
                bootstyle="light-toolbutton"
            ).pack(side="right", padx=5)

    def create_download_section(self, container):
        download_frame = ttk.Frame(container)
        download_frame.pack(fill="x", pady=15)
        
        # שורת כפתורים
        buttons_row = ttk.Frame(download_frame)
        buttons_row.pack(fill="x", pady=(0, 15))
        
        # כפתור הורדה
        download_button = ttk.Button(
            buttons_row,
            text="התחל הורדה",
            command=self.download_video,
            bootstyle="light",
            width=15
        )
        download_button.pack(side="left", padx=5)
        
        # כפתור עצירה
        self.stop_button = ttk.Button(
            buttons_row,
            text="עצור הורדה",
            command=self.stop_download,
            state="disabled",
            bootstyle="danger-outline",
            width=15
        )
        self.stop_button.pack(side="left", padx=5)
        
        # פס התקדמות
        progress_frame = ttk.Frame(download_frame)
        progress_frame.pack(fill="x", pady=(5, 10))
        
        self.progress = ttk.Progressbar(
            progress_frame,
            bootstyle="light-striped",
            mode="determinate",
            length=550
        )
        self.progress.pack(fill="x", pady=5)
        
        # תווית סטטוס
        self.status_var = tk.StringVar(value="מוכן להורדה")
        status_label = ttk.Label(
            download_frame,
            textvariable=self.status_var,
            font=("Segoe UI", 10),
            bootstyle="light"
        )
        status_label.pack()

    def create_log_section(self, container):
        log_frame = ttk.LabelFrame(container, text="לוג פעילות", padding="15", style="WhiteLabel.TLabelframe")
        log_frame.pack(fill="both", expand=True, pady=(15, 0))
        
        self.log_text = tk.Text(
            log_frame,
            height=20,
            font=("Consolas", 9),
            wrap="word",
            bg="#2c2c2c",
            fg="#ffffff"
        )
        scrollbar = ttk.Scrollbar(log_frame, bootstyle="dark-round")
        scrollbar.config(command=self.log_text.yview)
        self.log_text.config(yscrollcommand=scrollbar.set)
        self.log_text.pack(side="left", fill="both", expand=True)
        scrollbar.pack(side="right", fill="y")

    def show_context_menu(self, event):
        try:
            self.url_context_menu.tk_popup(event.x_root, event.y_root)
        finally:
            self.url_context_menu.grab_release()

    def select_directory(self):
        directory = filedialog.askdirectory()
        if directory:
            self.output_path.delete(0, tk.END)
            self.output_path.insert(0, directory)

    def copy_url(self, event=None):
        url = self.url_entry.get().strip()
        if url:
            self.root.clipboard_clear()
            self.root.clipboard_append(url)
            self.status_var.set("הקישור הועתק")
        else:
            self.status_var.set("אין קישור להעתקה")

    def paste_url(self, event=None):
        try:
            clipboard_text = self.root.clipboard_get()
            self.url_entry.delete(0, tk.END)
            self.url_entry.insert(0, clipboard_text)
            self.status_var.set("הקישור הודבק")
        except:
            self.status_var.set("אין טקסט בלוח ההעתקה")

    def cut_url(self, event=None):
        """גזירת הטקסט משדה ה-URL והעתקתו ללוח"""
        url = self.url_entry.get().strip()
        if url:
            self.root.clipboard_clear()
            self.root.clipboard_append(url)
            self.url_entry.delete(0, tk.END)
            self.status_var.set("הקישור נגזר")
        else:
            self.status_var.set("אין קישור לגזירה")
            
    def select_all(self, event=None):
        """בחירת כל הטקסט בשדה"""
        self.url_entry.select_range(0, tk.END)
        self.url_entry.icursor(tk.END)
        return "break"

    def delete_selection(self, event=None):
        """מחיקת הטקסט המסומן"""
        if self.url_entry.selection_present():
            self.url_entry.delete("sel.first", "sel.last")
        return "break"

    def backspace(self, event=None):
        """מחיקת תו אחד אחורה או את הבחירה"""
        if self.url_entry.selection_present():
            self.url_entry.delete("sel.first", "sel.last")
        else:
            current_pos = self.url_entry.index(tk.INSERT)
            if current_pos > 0:
                self.url_entry.delete(current_pos-1)
        return "break"
        
    def check_clipboard_for_youtube(self):
        """בדיקת לוח העתקה לחיפוש כתובת יוטיוב"""
        try:
            clipboard_text = self.root.clipboard_get()
            if "youtube.com" in clipboard_text or "youtu.be" in clipboard_text:
                self.url_entry.delete(0, tk.END)
                self.url_entry.insert(0, clipboard_text)
                self.status_var.set("קישור יוטיוב זוהה והודבק מהלוח")
                return True
            else:
                self.status_var.set("לא נמצא קישור יוטיוב בלוח ההעתקה")
                return False
        except Exception as e:
            self.status_var.set("שגיאה בגישה ללוח ההעתקה")
            return False

    def log_message(self, message):
        try:
            # ניסיון ראשון עם הקידוד מקורי
            self.root.after(0, lambda msg=message: self._update_log(msg))
        except Exception as e:
            print(f"שגיאה בלוג: {str(e)}")
    
    def _update_log(self, message):
        """עדכון חלונית הלוג - נקרא מתוך thread ראשי בלבד"""
        try:
            self.log_text.insert(tk.END, f"{message}\n")
            self.log_text.see(tk.END)
        except Exception as e:
            print(f"שגיאה בעדכון לוג: {str(e)}")

    def save_to_file(self, text, filename):
        try:
            with open(filename, 'w', encoding='utf-8') as f:
                f.write(text)
        except UnicodeError:
            try:
                with open(filename, 'w', encoding='cp1255') as f:
                    f.write(text)
            except Exception as e:
                self.log_message(f"שגיאה בשמירת הקובץ: {str(e)}")
        except Exception as e:
            self.log_message(f"שגיאה בשמירת הקובץ: {str(e)}")

    def check_ffmpeg(self):
        """בדיקה אם קובץ FFMPEG קיים בתיקיית התוכנה"""
        ffmpeg_path = os.path.join(os.path.dirname(__file__), "ffmpeg.exe")
        if not os.path.exists(ffmpeg_path):
            self.log_message(f"קובץ חסר: ffmpeg.exe")
            return False
            
        yt_dlp_path = os.path.join(os.path.dirname(__file__), "yt-dlp.exe")
        if not os.path.exists(yt_dlp_path):
            self.log_message(f"קובץ חסר: yt-dlp.exe")
            return False
            
        return True

    def download_video(self):
        url = self.url_entry.get().strip()
        output_path = self.output_path.get().strip()
        
        # בדיקות תקינות
        if not url:
            messagebox.showerror("שגיאה", "יש להזין קישור יוטיוב תקין")
            return
        if not output_path:
            messagebox.showerror("שגיאה", "יש לבחור תיקיית שמירה")
            return
        
        # יצירת תיקיית היעד אם לא קיימת
        try:
            os.makedirs(output_path, exist_ok=True)
        except Exception as e:
            messagebox.showerror("שגיאה", f"לא ניתן ליצור את תיקיית היעד: {str(e)}")
            return
        
        # בניית פקודת ההורדה
        command = self.build_download_command(url, output_path)
        
        # הצגת הפקודה בלוג לצורך דיבוג
        self.log_message(f"מפעיל פקודה: {' '.join(command)}")
        
        # הפעלת ההורדה
        self.status_var.set("מוריד...")
        self.progress.config(value=0)
        self.progress.start()
        self.stop_button.config(state="normal")
        
        threading.Thread(target=lambda: self.run_download(command), daemon=True).start()

    def build_download_command(self, url, output_path):
        """בניית פקודת ההורדה עם כל הפרמטרים הדרושים"""
        # ביטול דרישה לנתיב מלא - ניסיון לקרוא מהתיקייה הנוכחית
        yt_dlp_path = "yt-dlp.exe"
        ffmpeg_path = "ffmpeg.exe"
        
        # אם קבצי העזר נמצאים בתיקיית התוכנה, נשתמש בהם
        if os.path.exists(os.path.join(os.path.dirname(__file__), "yt-dlp.exe")):
            yt_dlp_path = os.path.join(os.path.dirname(__file__), "yt-dlp.exe")
        
        if os.path.exists(os.path.join(os.path.dirname(__file__), "ffmpeg.exe")):
            ffmpeg_path = os.path.join(os.path.dirname(__file__), "ffmpeg.exe")
            
        self.log_message(f"משתמש ב-yt-dlp: {yt_dlp_path}")
        self.log_message(f"משתמש ב-ffmpeg: {ffmpeg_path}")
        
        # בניית פקודה בסיסית
        command = [
            yt_dlp_path,
            "--no-check-certificate",
            "--force-ipv4",
            "--geo-bypass",
            "--no-part",
            "--no-mtime",
            "--ffmpeg-location", ffmpeg_path,
            "--progress",
            "--newline"
        ]
        
        # הוספת פרמטרים לעקיפת נטפרי
        if hasattr(self, 'netfree_bypass_var') and self.netfree_bypass_var.get():
            self.log_message("משתמש במצב תאימות לנטפרי")
            command.extend([
                "--ignore-errors",
                "--ignore-config",
                "--skip-unavailable-fragments",
                "--user-agent", "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36",
                "--referer", "https://www.google.com/"
            ])
        
        # טיפול בסוג תוכן
        content_type = self.content_type.get()
        if content_type in ["playlist", "channel"]:
            command.extend(["--yes-playlist"])
        else:
            command.extend(["--no-playlist"])
        
        # קביעת קובץ יעד
        if content_type in ["playlist", "channel"]:
            output_template = os.path.join(output_path, "%(playlist_title)s", "%(title)s.%(ext)s")
        else:
            output_template = os.path.join(output_path, "%(title)s.%(ext)s")
        command.extend(["-o", output_template])
        
        # בחירת פורמט הורדה
        if self.format_var.get() == "audio":
            if hasattr(self, 'netfree_bypass_var') and self.netfree_bypass_var.get():
                # פורמט שעובד טוב יותר עם נטפרי
                command.extend([
                    "-f", "bestaudio[ext=m4a]/bestaudio",  # נסה להוריד m4a שפחות נחסם
                    "--extract-audio",
                    "--audio-format", "mp3",
                    "--audio-quality", "0",
                    "--postprocessor-args", "ffmpeg:-threads 1"  # הגבלת thread לתהליך ffmpeg
                ])
            else:
                # פורמט רגיל
                command.extend([
                    "-f", "ba",
                    "--extract-audio",
                    "--audio-format", "mp3",
                    "--audio-quality", "0"
                ])
        else:
            # תמיד להוריד באיכות הטובה ביותר הזמינה
            command.extend([
                "-f", "bv*+ba/b"
            ])
        
        # הוספת ה-URL בסוף הפקודה
        command.append(url)
        
        return command

    def run_download(self, command):
        """הפעלת תהליך ההורדה וניטור התקדמותו"""
        try:
            # הוספת startupinfo כדי להסתיר את הקונסול
            startupinfo = subprocess.STARTUPINFO()
            startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
            startupinfo.wShowWindow = subprocess.SW_HIDE
            
            # יצירת תהליך עם הפרמטרים הנכונים
            self.log_message("מתחיל תהליך הורדה...")
            self.download_process = subprocess.Popen(
                command,
                stdout=subprocess.PIPE,
                stderr=subprocess.PIPE,
                universal_newlines=True,
                encoding='cp1255',  # משתמש בקידוד שמתאים לעברית בחלונות 
                startupinfo=startupinfo,
                creationflags=subprocess.CREATE_NO_WINDOW  # מניעת חלון מהבהב
            )
            
            # קריאת הפלט בזמן אמת
            self.log_message("תהליך ההורדה החל")
            
            while True:
                # קריאת שורה מהפלט הסטנדרטי
                line = self.download_process.stdout.readline()
                
                # אם אין יותר פלט (סוף הקובץ), יוצאים מהלולאה
                if not line:
                    break
                
                # מנקים רווחים מיותרים וסימני שורה חדשה
                line = line.strip()
                
                # שליחה ללוג רק אם השורה אינה ריקה
                if line:
                    self.log_message(line)
                
                # עדכון אחוזי התקדמות
                if "[download]" in line and "%" in line:
                    try:
                        parts = line.split()
                        for part in parts:
                            if "%" in part:
                                percent = part.replace('%','')
                                try:
                                    percent_value = float(percent)
                                    self.root.after(0, lambda p=percent: self.status_var.set(f"מוריד... {p}%"))
                                    self.root.after(0, lambda p=percent_value: self.progress.config(value=p))
                                except ValueError:
                                    pass  # אם המספר לא תקין, מתעלמים
                                break
                    except Exception as e:
                        self.log_message(f"שגיאה בעיבוד התקדמות: {str(e)}")
                
                # מידע על הקובץ שמורידים
                elif "Destination:" in line:
                    try:
                        filename = line.split("Destination:", 1)[1].strip()
                        self.log_message(f"מוריד: {filename}")
                    except:
                        pass
            
            # בדיקת שגיאות מהפלט השגיאות
            stderr_output = ""
            for line in self.download_process.stderr:
                stderr_output += line
                self.log_message(f"שגיאה: {line.strip()}")
            
            # המתנה לסיום התהליך
            self.download_process.wait()
            exit_code = self.download_process.returncode
            
            self.log_message(f"תהליך ההורדה הסתיים עם קוד יציאה: {exit_code}")
            
            # בדיקת הצלחת התהליך
            if exit_code == 0:
                self.root.after(0, lambda: messagebox.showinfo("הצלחה", "ההורדה הושלמה בהצלחה"))
                self.root.after(0, lambda: self.status_var.set("ההורדה הושלמה בהצלחה!"))
                self.log_message("ההורדה הושלמה בהצלחה!")
            else:
                error_msg = stderr_output if stderr_output else "שגיאה לא ידועה"
                self.root.after(0, lambda: messagebox.showerror("שגיאה בהורדה", f"קוד שגיאה: {exit_code}\n{error_msg}"))
                self.root.after(0, lambda: self.status_var.set(f"שגיאה בהורדה"))
                self.log_message(f"שגיאה בהורדה. קוד: {exit_code}")
            
        except Exception as e:
            self.log_message(f"שגיאה בהפעלת תהליך ההורדה: {str(e)}")
            self.root.after(0, lambda err=str(e): messagebox.showerror("שגיאה", f"שגיאה בהפעלת תהליך ההורדה: {err}"))
            self.root.after(0, lambda: self.status_var.set(f"שגיאה בהפעלת ההורדה"))
        
        finally:
            # ניקוי משאבים בכל מקרה
            self.root.after(0, lambda: self.progress.stop())
            self.root.after(0, lambda: self.progress.config(value=0))
            self.root.after(0, lambda: self.stop_button.config(state="disabled"))

    def stop_download(self):
        """עצירת ההורדה הנוכחית"""
        if hasattr(self, 'download_process') and self.download_process:
            self.download_process.terminate()
            self.status_var.set("ההורדה הופסקה")
            self.progress.stop()
            self.progress.config(value=0)
            self.stop_button.config(state="disabled")
            self.log_message("ההורדה הופסקה על ידי המשתמש")

    def handle_keypress(self, event):
        """טיפול בלחיצות מקשים כלליות"""
        if event.state & 0x4:  # בדיקה אם Control לחוץ
            key = event.char.lower()
            if key in ['ש', '\u05e9', 'a']:  # Select All (ש)
                return self.select_all(event)
            elif key in ['ב', '\u05d1', 'c']:  # Copy (ב)
                return self.copy_url(event)
            elif key in ['ה', '\u05d4', 'v']:  # Paste (ה)
                return self.paste_url(event)
            elif key in ['ס', '\u05e1', 'x']:  # Cut (ס)
                return self.cut_url(event)
        return None

# נקודת כניסה לתוכנה
if __name__ == "__main__":
    root = tk.Tk()
    
    if hasattr(sys, '_MEIPASS'):  # בדיקה אם התוכנית רצה כקובץ EXE
        try:
            import win32gui, win32con
            hwnd = win32gui.GetForegroundWindow()
            win32gui.ShowWindow(hwnd, win32con.SW_HIDE)
        except ImportError:
            pass  # אם win32gui לא זמין, נמשיך בלעדיו
    
    app = YouTubeDownloaderApp(root)
    root.mainloop()
